@@ -86,8 +86,8 @@ struct RrdaResource::pImpl {
 
     const unsigned char* work = gz_header_check(data_first, area_size);
     if (work == NULL) {
-      // キーが違うかデータが壊れている
-      return false;
+      // zip ヘッダがない場合
+      work = data_first;
     }
     long zbody_size = area_size - static_cast<long>(work - data_first);
     if (! gunzip_data(work, zbody_size)) {
